//
// C++ Interface: CFogEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CFOGEDITDLG_H
#define CFOGEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_fogdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CFogEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CFogEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CFogEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColor();
    
private slots:
 
protected:
    Ui::FogEditDlg ui;    
    FolderListItem *point;
    QColor mycolor;
    
private:
    QWidget *myParent;
};
#endif
